@@ -1,60 +1,3 @@
-#' Get the nth element of each vector in a list of numeric or character vectors.
-#'
-#' These are faster implementations of procedures that could very easily be done
-#' with [purrr::map_dbl] or [purrr::map_chr].
-#'
-#' @param char_list A list of character vectors.
-#' @param n The index of the element that you want from each vector. If
-#'   `char_list` (or `num_list`) is of length 1, this can be any length and
-#'   those indices will be extracted from `char_list[[1]]` (or `num_list[[1]]`).
-#'   Otherwise, this must either be of length 1 or the same length as
-#'   `char_list`. All of this is to say that the function is vectorised over
-#'   this argument.
-#'
-#' @return A list.
-#'
-#' @examples
-#' str_list_nth_elems_(list(c("a", "b", "c"), c("d", "f", "a")), 2)
-#' num_list_nth_elems_(list(1:5, 0:2), 4)
-#' @noRd
-str_list_nth_elems <- function(char_list, n) {
-  checkmate::assert_list(char_list, min.len = 1)
-  checkmate::assert_integerish(n, min.len = 1)
-  lcl <- length(char_list)
-  ln <- length(n)
-  if (lcl > 1 && ln > 1 && lcl != ln) {
-    custom_stop("
-      If both `char_list` and `n` have lengths greater than 1,
-      then their lengths must be equal.
-      ", "
-      Your `char_list` has length {length(char_list)} and
-      your `n` has length {length(n)}.
-    ")
-  }
-  str_list_nth_elems_helper(char_list, n)
-}
-
-
-#' @rdname str_list_nth_elems
-#' @param num_list A list of numeric vectors.
-#' @noRd
-num_list_nth_elems <- function(num_list, n) {
-  checkmate::assert_list(num_list, min.len = 1)
-  checkmate::assert_integerish(n, min.len = 1)
-  lnl <- length(num_list)
-  ln <- length(n)
-  if (lnl > 1 && ln > 1 && lnl != ln) {
-    custom_stop("
-      If both `num_list` and `n` have lengths greater than 1,
-      then their lengths must be equal.
-      ", "
-      Your `num_list` has length {length(num_list)} and
-      your `n` has length {length(n)}.
-      ")
-  }
-  num_list_nth_elems_(num_list, n)
-}
-
 #' Construct the bullet point bits for `custom_stop()`.
 #'
 #' @param string The message for the bullet point.
@@ -68,7 +11,7 @@ custom_bullet <- function(string) {
   string %>%
     stringr::str_replace_all("\\s+", " ") %>%
     {
-      glue::glue("    * {.}")
+      stringr::str_glue("    * {.}")
     }
 }
 
@@ -76,7 +19,7 @@ custom_condition_prep <- function(main_message, ..., .envir = parent.frame()) {
   checkmate::assert_string(main_message)
   main_message %<>%
     stringr::str_replace_all("\\s+", " ") %>%
-    glue::glue(.envir = .envir) %>%
+    stringr::str_glue(.envir = .envir) %>%
     stringr::str_trim()
   out <- main_message
   dots <- unlist(list(...))
@@ -85,10 +28,10 @@ custom_condition_prep <- function(main_message, ..., .envir = parent.frame()) {
       stop("\nThe arguments in ... must all be of character type.")
     }
     dots %<>%
-      vapply(glue::glue, character(1), .envir = .envir) %>%
+      vapply(stringr::str_glue, character(1), .envir = .envir) %>%
       vapply(custom_bullet, character(1))
     out %<>% {
-      glue::glue_collapse(c(., dots), sep = "\n")
+      stringr::str_c(c(., dots), collapse = "\n")
     }
   }
   out
@@ -113,6 +56,60 @@ custom_warn <- function(main_message, ..., .envir = parent.frame()) {
   rlang::warn(custom_condition_prep(main_message, ..., .envir = .envir))
 }
 
+#' Assert that two objects have compatible lengths.
+#'
+#' Compatible means that either both have length less than or equal to 1, or
+#' both have the same length.
+#'
+#' @param x, y Objects
+#'
+#' @return `TRUE`, invisibly if the lengths are compatible. Otherwise an error
+#'   is thrown.
+#'
+#' @noRd
+assert_compatible_lengths <- function(x, y) {
+  x_sym <- rlang::ensym(x)
+  y_sym <- rlang::ensym(y)
+  checkmate::assert_vector(x)
+  checkmate::assert_vector(y)
+  if (length(x) > 1 && length(y) > 1) {
+    if (length(x) != length(y)) {
+      custom_stop(
+        "If both `{x_sym}` and `{y_sym}` have lengths greater than 1,
+        then their lengths must be equal.",
+        "`{x_sym}` has length {length(x)}.",
+        "`{y_sym}` has length {length(y)}.",
+        .envir = list(x = x, y = y, x_sym = x_sym, y_sym = y_sym)
+      )
+    }
+  }
+  invisible(TRUE)
+}
+
+#' Assert that the elements of a list have a common length.
+#'
+#' @param lst A list.
+#'
+#' @return `TRUE` (invisibly) if the elements have a common length. Otherwise,
+#'   an error is thrown.
+#'
+#' @noRd
+assert_lst_elems_common_length <- function(lst) {
+  lst_sym <- rlang::ensym(lst)
+  checkmate::assert_list(lst)
+  l <- length(lst)
+  if (l <= 1) {
+    return(invisible(TRUE))
+  }
+  good <- lst_elems_common_length(lst, as.double(l))
+  if (!good) {
+    custom_stop("Elements of `{lst_sym}` do not have a common length.",
+      .envir = list(lst_sym = lst_sym)
+    )
+  }
+  invisible(TRUE)
+}
+
 #' Generate an error due to an incompatible combination of arguemnt lengths.
 #'
 #' @param string A character vector.
@@ -122,16 +119,22 @@ custom_warn <- function(main_message, ..., .envir = parent.frame()) {
 #' @noRd
 err_string_len <- function(string, sym, replacement_sym = NULL) {
   sym_sym <- rlang::enexpr(sym)
-  sym_str <- as.character(sym_sym)
-  if (!is.null(replacement_sym)) sym_str <- replacement_sym
-  sym_len <- length(sym)
+  if (!is.null(replacement_sym)) {
+    sym_str <- replacement_sym
+  } else {
+    sym_str <- as.character(sym_sym)
+  }
   custom_stop(
     "
     When `string` has length greater than 1,
     `{sym_str}` must either be length 1 or have the same length as `string`.
     ",
     "Your `string` has length {length(string)}.",
-    "Your `{sym_str}` has length {sym_len}."
+    "Your `{sym_str}` has length {sym_len}.",
+    .envir = list(
+      sym_str = sym_str, sym_len = length(sym),
+      string = string
+    )
   )
 }
 
@@ -157,19 +160,21 @@ verify_string_n <- function(string, n, replacement_n_sym = NULL) {
 
 verify_string_pattern_n <- function(string, pattern, n,
                                     replacement_n_sym = NULL) {
-  verify_string_pattern(string, pattern)
+  if (!is.null(replacement_n_sym)) {
+    n_sym_str <- replacement_n_sym
+  } else {
+    n_sym_str <- as.character(rlang::ensym(n))
+  }
   verify_string_n(string, n, replacement_n_sym)
-  n_sym_str <- "n"
-  if (!is.null(replacement_n_sym)) n_sym_str <- replacement_n_sym
+  verify_string_pattern(string, pattern)
   if (length(pattern) > 1 && length(n) > 1 &&
     length(pattern) != length(n)) {
     custom_stop(
-      "
-                If `pattern` and `{n_sym_str}` both have length greater than 1,
-                their lengths must be equal.
-                ",
+      "If `pattern` and `n` both have length greater than 1,
+      their lengths must be equal.",
       "Your `pattern` has length {length(pattern)}.",
-      "Your `{n_sym_str}` has length {length(n)}."
+      "Your `{n_sym_str}` has length {length(n)}.",
+      .envir = list(pattern = pattern, n = n, n_sym_str = n_sym_str)
     )
   }
   invisible(TRUE)
