@@ -1,4 +1,3 @@
-context("CamelCase")
 test_that("str_split_camel_case()` works", {
   expect_equal(
     str_split_camel_case(c(
@@ -23,4 +22,5 @@ test_that("str_split_camel_case()` works", {
     ) %>%
       lapply(str_to_lower)
   )
+  expect_equal(str_split_camel_case(character()), list())
 })
