@@ -2,7 +2,7 @@ test_that("`str_extract_currencies()` works", {
   string <- "35.00 $1.14 abc5 $3.8 77"
   expect_equal(
     str_extract_currencies(string),
-    tibble::tibble(
+    data.frame(
       string_num = 1, string = string,
       curr_sym = c("", "$", "c", "$", " "),
       amount = c(35, 1.14, 5, 3.8, 77)
@@ -15,7 +15,7 @@ test_that("`str_extract_currencies()` works", {
   reps <- c(2, 3, 1, 1)
   expect_equal(
     str_extract_currencies(string),
-    tibble::tibble(
+    data.frame(
       string_num = rep(seq_along(string), reps),
       string = rep(string, reps),
       curr_sym = c("", "$", "c", "$", " ", "$", "£"),
@@ -35,7 +35,7 @@ test_that("`str_nth_currency()` works", {
   string <- c("ab3 13", "$1")
   expect_equal(
     str_nth_currency(string, n = 2),
-    tibble::tibble(
+    data.frame(
       string_num = seq_along(string), string = string,
       curr_sym = c(" ", NA), amount = c(13, NA)
     )
@@ -44,62 +44,48 @@ test_that("`str_nth_currency()` works", {
   expect_equal(str_nth_currency(string, c(
     1,
     2, 1
-  )), tibble::tibble(
+  )), data.frame(
     string_num = seq_along(string), string = string,
     curr_sym = c("", "$", NA), amount = c(35, 3.8, NA)
   ))
   string <- c("ab3 13", "$1", "35.00 $1.14", "abc5 $3.8", "stuff")
   expect_equal(
     str_nth_currency(string, n = 2),
-    structure(list(string_num = 1:5, string = c(
-      "ab3 13", "$1", "35.00 $1.14",
-      "abc5 $3.8", "stuff"
-    ), curr_sym = c(" ", NA, "$", "$", NA), amount = c(
-      13,
-      NA, 1.14, 3.8, NA
-    )), row.names = c(NA, -5L), class = c(
-      "tbl_df",
-      "tbl", "data.frame"
-    ))
+    data.frame(
+      string_num = 1:5,
+      string = c("ab3 13", "$1", "35.00 $1.14", "abc5 $3.8", "stuff"),
+      curr_sym = c(" ", NA, "$", "$", NA),
+      amount = c(13, NA, 1.14, 3.8, NA)
+    )
   )
   expect_equal(
     str_nth_currency(string, c(1, 2, 1, 2, 1)),
-    structure(list(string_num = 1:5, string = c(
-      "ab3 13", "$1", "35.00 $1.14",
-      "abc5 $3.8", "stuff"
-    ), curr_sym = c("b", NA, "", "$", NA), amount = c(
-      3,
-      NA, 35, 3.8, NA
-    )), row.names = c(NA, -5L), class = c(
-      "tbl_df",
-      "tbl", "data.frame"
-    ))
+    data.frame(
+      string_num = 1:5,
+      string = c("ab3 13", "$1", "35.00 $1.14", "abc5 $3.8", "stuff"),
+      curr_sym = c("b", NA, "", "$", NA),
+      amount = c(3, NA, 35, 3.8, NA)
+    )
   )
   expect_equal(
     str_first_currency(string),
-    structure(list(string_num = 1:5, string = c(
+    data.frame(string_num = 1:5, string = c(
       "ab3 13", "$1", "35.00 $1.14",
       "abc5 $3.8", "stuff"
     ), curr_sym = c("b", "$", "", "c", NA), amount = c(
       3,
       1, 35, 5, NA
-    )), row.names = c(NA, -5L), class = c(
-      "tbl_df", "tbl",
-      "data.frame"
     ))
   )
   expect_equal(
     str_last_currency(string),
-    structure(list(
+    data.frame(
       string_num = 1:5, string = c(
         "ab3 13", "$1", "35.00 $1.14",
         "abc5 $3.8", "stuff"
       ), curr_sym = c(" ", "$", "$", "$", NA),
       amount = c(13, 1, 1.14, 3.8, NA)
-    ), row.names = c(NA, -5L), class = c(
-      "tbl_df",
-      "tbl", "data.frame"
-    ))
+    )
   )
   expect_error(str_nth_currency(as.character(1:3), 1:7),
     paste(
